==> net.sf.jasperreports.engine.source_6.6.0.jar: net/sf/jasperreports/ant/UpdaterElement.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2018 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.ant;

import org.apache.tools.ant.BuildException;

import net.sf.jasperreports.engine.util.ReportUpdater;


/**
 * Utility class that provides a {@link net.sf.jasperreports.engine.util.ReportUpdater ReportUpdater} 
 * implementation
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public class UpdaterElement
{


	/**
	 *
	 */
	private ReportUpdater updater;


	/**
	 *
	 */
	public void addText(String className)
	{
		if (className != null)
		{
			try
			{
				Class<?> clazz = JRAntCompileTask.class.getClassLoader().loadClass(className);
				updater = (ReportUpdater)clazz.newInstance();
			}
			catch (ClassNotFoundException e)
			{
				throw new BuildException(e);
			}
			catch (IllegalAccessException e)
			{
				throw new BuildException(e);
			}
			catch (InstantiationException e)
			{
				throw new BuildException(e);
			}
		}
	}
	
	/**
	 * 
	 */
	public ReportUpdater getUpdater()
	{
		return updater;
	}

}

==> net.sf.jasperreports.engine.source_6.15.0.jar: net/sf/jasperreports/ant/UpdaterElement.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2019 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.ant;

import java.lang.reflect.InvocationTargetException;

import org.apache.tools.ant.BuildException;

import net.sf.jasperreports.engine.util.ReportUpdater;


/**
 * Utility class that provides a {@link net.sf.jasperreports.engine.util.ReportUpdater ReportUpdater} 
 * implementation
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public class UpdaterElement
{


	/**
	 *
	 */
	private ReportUpdater updater;


	/**
	 *
	 */
	public void addText(String className)
	{
		if (className != null)
		{
			try
			{
				Class<?> clazz = JRAntCompileTask.class.getClassLoader().loadClass(className);
				updater = (ReportUpdater)clazz.getDeclaredConstructor().newInstance();
			}
			catch (ClassNotFoundException | IllegalAccessException | InstantiationException 
				| NoSuchMethodException | InvocationTargetException e)
			{
				throw new BuildException(e);
			}
		}
	}
	
	/**
	 * 
	 */
	public ReportUpdater getUpdater()
	{
		return updater;
	}

}
